Name:          marisa
Version:       0.2.6
Release:       1
Summary:       Matching Algorithm with Recursively Implemented StorAge

License:       BSD-2-Clause or LGPL-2.1-or-later
URL:           https://github.com/s-yata/marisa-trie
Source0:       https://github.com/s-yata/marisa-trie/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires: swig perl-devel perl-generators python3-devel ruby-devel g++
BuildRequires: autoconf automake libtool

%description
MARISA is a static and space-efficient trie data structure. And libmarisa is a C++
library to provide an implementation of MARISA. Also, the package of libmarisa contains
a set of command line tools,which build and operate a MARISA-based dictionary.

%package       devel
Summary:       Development files for marisa
Requires:      %{name} = %{version}-%{release}
Provides:      %{name}-tools = %{version}-%{release}
Obsoletes:     %{name}-tools < %{version}-%{release}

%description   devel
The marisa-devel package contains libraries and header files for
developing applications that use marisa.

%package -n python3-marisa
Summary:       Python3 bindings for marisa
Requires:      %{name} = %{version}-%{release}
%{?python_provide:%python_provide python3-marisa}

%description -n python3-marisa
Python3 bindings for marisa.

%package perl
Summary:       Perl bindings for marisa
Requires:      %{name} = %{version}-%{release}

%description perl
Perl bindings for marisa.

%package ruby
Summary:       Ruby bindings for marisa
Requires:      %{name} = %{version}-%{release}
Requires:      ruby(release)

%description ruby
Ruby bindings for marisa.


%prep
%autosetup -n %{name}-trie-%{version} -p1

%build
%set_build_flags
autoreconf -i
%configure --disable-static
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
%make_build

cd bindings/perl
%{__perl} Makefile.PL INC="-I%{_builddir}/marisa-trie-%{version}/include" \
LIBS="-L%{_builddir}/marisa-trie-%{version}/lib/marisa/.libs -lmarisa" INSTALLDIRS=vendor
%make_build
cd -

%make_build --directory=bindings swig-python

cd bindings/python
%{__python3} setup.py build_ext --include-dirs="%{_builddir}/marisa-trie-%{version}/include" \
--library-dirs="%{_builddir}/marisa-trie-%{version}/lib/marisa/.libs"
%py3_build
cd -

cd bindings
%make_build swig-ruby
cd -

cd bindings/ruby
ruby extconf.rb --with-opt-include="%{_builddir}/marisa-trie-%{version}/include" \
--with-opt-lib="%{_builddir}/marisa-%{version}/lib/marisa/.libs" --vendor
%make_build
cd -

%install
%make_install

cd bindings/perl
%make_install
%{_fixperms} -c %{buildroot}%{perl_vendorarch}/*
cd -

cd bindings/python
%py3_install
cd -

cd bindings/ruby
%make_install
cd -

%delete_la
find $RPM_BUILD_ROOT -name 'perllocal.pod' -delete

%post
/sbin/ldconfig

%postun
/sbin/ldconfig

%files
%doc docs/style.css AUTHORS README.md docs/readme.en.html
%lang(ja) %doc docs/readme.ja.html
%{_libdir}/libmarisa.so.*

%files devel
%{_includedir}/marisa*
%{_libdir}/{*.so,pkgconfig/*.pc}
%{_bindir}/*

%files -n python3-marisa
%{python3_sitearch}/__pycache__/marisa*
%{python3_sitearch}/{_marisa*.so,marisa.py}
%{python3_sitearch}/marisa-0.0.0-py%{python3_version}.egg-info

%files perl
%{perl_vendorarch}/{marisa.pm,auto/marisa}
%exclude %{perl_vendorarch}/auto/marisa/.packlist
%exclude %{perl_vendorarch}/sample.pl
%exclude %{perl_vendorarch}/benchmark.pl

%files ruby
%{ruby_vendorarchdir}/marisa.so

%changelog
* Tue Oct 17 2023 xu_ping <707078654@qq.com> - 0.2.6-1
- Upgrade version to 0.2.6

* Tue May 10 2022 chenchen <chen_aka_jan@163.com> - 0.2.4-41
- License compliance rectification

* Wed Mar 30 2022 chenchen <chen_aka_jan@163.com> - 0.2.4-40
- using macros to get python versions by python3.10+ 

* Wed Jun 09 2021 wulei <wulei80@huawei.com> - 0.2.4-39
- fixes failed: error: no acceptable C compiler found in PATH

* Wed Oct 21 2020 Ge Wang <wangge20@huawei.com> - 0.2.4-38
- remove python2

* Thu Dec 12 2019 daiqianwen <daiqianwen@huawei.com> - 0.2.4-37
- Package init






